@@ -5,7 +5,6 @@ import unittest
 import pyproj
 
 from geodataset.tools import open_netcdf
-
 from geodataset.tests.base_for_tests import BaseForTests
 
 
@@ -16,12 +15,13 @@ class ToolsTests(BaseForTests):
 
     def test_open_netcdf(self):
         for nc_file in self.nc_files:
-            ds = open_netcdf(nc_file)
-            print(nc_file, ds.lonlat_names)
-            self.assertIsInstance(ds.lonlat_names[0], str)
-            self.assertIsInstance(ds.lonlat_names[1], str)
-            self.assertIsInstance(ds.variable_names, list)
-            self.assertIsInstance(ds.variable_names[0], str)
+            with self.subTest(nc_file=nc_file):
+                ds = open_netcdf(nc_file)
+                print(nc_file, ds.lonlat_names)
+                self.assertIsInstance(ds.lonlat_names[0], str)
+                self.assertIsInstance(ds.lonlat_names[1], str)
+                self.assertIsInstance(ds.variable_names, list)
+                self.assertIsInstance(ds.variable_names[0], str)
 
     def test_get_lonlat_arrays(self):
         for nc_file in self.nc_files:
@@ -42,6 +42,7 @@ class ToolsTests(BaseForTests):
         for nc_file in self.nc_files:
             with self.subTest(nc_file=nc_file):
                 ds = open_netcdf(nc_file)
+                self.assertIsInstance(ds.grid_mapping_variable, str)
                 self.assertIsInstance(ds.projection, pyproj.Proj)
 
 if __name__ == "__main__":
